use axum::Router;
use sqlx::SqlitePool;
use std::sync::Arc;
use tokio::net::TcpListener;
use tower_sessions::{MemoryStore, SessionManagerLayer};

mod station;

/// Starts the main application.
pub async fn start(listener: TcpListener, db: SqlitePool) {
    let session_store = MemoryStore::default();
    let session_layer = SessionManagerLayer::new(session_store);

    let app = Router::new()
        .nest("/station", station::routes())
        .with_state(Arc::new(db))
        .layer(session_layer);

    axum::serve(listener, app).await.unwrap();
}
